pub struct Chunk { /* private fields */ }Expand description
A terrain chunk that contains a list of terrain tiles.
Implementations
Sourceimpl Chunk
impl Chunk
Sourcepub fn set_entity_at(&mut self, local_pos: GridLocalPos, entity: Entity)
pub fn set_entity_at(&mut self, local_pos: GridLocalPos, entity: Entity)
Sets the entity at the specified local tile position within this chunk.
Sourcepub fn get_entity_at(&self, local_pos: GridLocalPos) -> Option<Entity>
pub fn get_entity_at(&self, local_pos: GridLocalPos) -> Option<Entity>
Gets the entity at the specified local tile position within this chunk, if it exists.
Sourcepub fn remove_entity(&mut self, entity: Entity)
pub fn remove_entity(&mut self, entity: Entity)
Removes the entity from all tiles it occupies in this chunk.
Sourcepub fn get_nearest_local_tile(world_pos: Vec2) -> GridLocalPos
pub fn get_nearest_local_tile(world_pos: Vec2) -> GridLocalPos
Converts a world position to a local tile position within this chunk.
Sourcepub fn get_tile_world_pos(pos: GridTilePos) -> Vec2
pub fn get_tile_world_pos(pos: GridTilePos) -> Vec2
Gets the center position of a tile.
Sourcepub fn local_pos_to_index(local_pos: GridLocalPos) -> usize
pub fn local_pos_to_index(local_pos: GridLocalPos) -> usize
Converts a local tile position to an index in the tiles vector.