pub struct Grid { /* private fields */ }Expand description
The main terrain grid resource that holds all the terrain chunks and their respective tiles.
Implementations
Sourceimpl Grid
impl Grid
Sourcepub fn get_entity(
&self,
chunk_pos: GridChunkPos,
local_pos: GridLocalPos,
) -> Option<Entity>
pub fn get_entity( &self, chunk_pos: GridChunkPos, local_pos: GridLocalPos, ) -> Option<Entity>
Gets the entity at the specified chunk and local tile position in the grid, if it exists.
Sourcepub fn set_entity(&mut self, grid_entity: &GridEntity, entity: Entity)
pub fn set_entity(&mut self, grid_entity: &GridEntity, entity: Entity)
Adds the specified entity to the grid at the positions occupied by the entity footprint.
Sourcepub fn remove_entity(&mut self, entity: Entity)
pub fn remove_entity(&mut self, entity: Entity)
Removes the specified entity from the grid, freeing up the tiles it occupied.
Sourcepub fn is_area_free(&self, entity: &GridEntity) -> bool
pub fn is_area_free(&self, entity: &GridEntity) -> bool
Check if the position and extent are valid for placement (no existing entities in the area).
Sourcepub fn get_nearest_tile(world_pos: Vec2) -> GridTilePos
pub fn get_nearest_tile(world_pos: Vec2) -> GridTilePos
Gets the nearest chunk and tile position (without subtile direction) for a given world position.
Sourcepub fn get_chunk_world_pos(chunk_pos: GridChunkPos) -> Vec2
pub fn get_chunk_world_pos(chunk_pos: GridChunkPos) -> Vec2
Gets the center world position of a given chunk.
Sourcepub fn get_tile_world_pos(pos: GridTilePos) -> Vec2
pub fn get_tile_world_pos(pos: GridTilePos) -> Vec2
Gets the center world position for a given chunk and local tile position.
pub fn set_parent(&mut self, parent: Entity)
pub fn get_parent(&self) -> Option<Entity>